import { RDSDataClient } from "./RDSDataClient";
import { BatchExecuteStatementInput } from "./types/BatchExecuteStatementInput";
import { BatchExecuteStatementOutput } from "./types/BatchExecuteStatementOutput";
import { BeginTransactionInput } from "./types/BeginTransactionInput";
import { BeginTransactionOutput } from "./types/BeginTransactionOutput";
import { CommitTransactionInput } from "./types/CommitTransactionInput";
import { CommitTransactionOutput } from "./types/CommitTransactionOutput";
import { ExecuteSqlInput } from "./types/ExecuteSqlInput";
import { ExecuteSqlOutput } from "./types/ExecuteSqlOutput";
import { ExecuteStatementInput } from "./types/ExecuteStatementInput";
import { ExecuteStatementOutput } from "./types/ExecuteStatementOutput";
import { RollbackTransactionInput } from "./types/RollbackTransactionInput";
import { RollbackTransactionOutput } from "./types/RollbackTransactionOutput";
export declare class RDSData extends RDSDataClient {
    /**
     * <p>Runs a batch SQL statement over an array of data.</p>
            <p>You can run bulk update and insert operations for multiple records using a DML
                statement with different parameter sets. Bulk operations can provide a significant
                performance improvement over individual insert and update operations.</p>
            <important>
                <p>If a call isn't part of a transaction because it doesn't include the
                        <code>transactionID</code> parameter, changes that result from the call are
                    committed automatically.</p>
            </important>
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} <p>There is an error in the call or in a SQL statement.</p>
     *   - {ForbiddenException} <p>There are insufficient privileges to make the call.</p>
     *   - {InternalServerErrorException} <p>An internal error occurred.</p>
     *   - {ServiceUnavailableError} <p>The service specified by the <code>resourceArn</code> parameter is not
                available.</p>
     *   - {StatementTimeoutException} <p>The execution of the SQL statement timed out.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    batchExecuteStatement(args: BatchExecuteStatementInput): Promise<BatchExecuteStatementOutput>;
    batchExecuteStatement(args: BatchExecuteStatementInput, cb: (err: any, data?: BatchExecuteStatementOutput) => void): void;
    /**
     * <p>Starts a SQL transaction.</p>
  
            <important>
                <p>A transaction can run for a maximum of 24 hours. A transaction is terminated and
                    rolled back automatically after 24 hours.</p>
                <p>A transaction times out if no calls use its transaction ID in three minutes.
                    If a transaction times out before it's committed, it's rolled back
                    automatically.</p>
                <p>DDL statements inside a transaction cause an implicit commit. We recommend
                    that you run each DDL statement in a separate <code>ExecuteStatement</code> call with
                    <code>continueAfterTimeout</code> enabled.</p>
            </important>
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} <p>There is an error in the call or in a SQL statement.</p>
     *   - {ForbiddenException} <p>There are insufficient privileges to make the call.</p>
     *   - {InternalServerErrorException} <p>An internal error occurred.</p>
     *   - {ServiceUnavailableError} <p>The service specified by the <code>resourceArn</code> parameter is not
                available.</p>
     *   - {StatementTimeoutException} <p>The execution of the SQL statement timed out.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    beginTransaction(args: BeginTransactionInput): Promise<BeginTransactionOutput>;
    beginTransaction(args: BeginTransactionInput, cb: (err: any, data?: BeginTransactionOutput) => void): void;
    /**
     * <p>Ends a SQL transaction started with the <code>BeginTransaction</code> operation and
                commits the changes.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} <p>There is an error in the call or in a SQL statement.</p>
     *   - {ForbiddenException} <p>There are insufficient privileges to make the call.</p>
     *   - {InternalServerErrorException} <p>An internal error occurred.</p>
     *   - {NotFoundException} <p>The <code>resourceArn</code>, <code>secretArn</code>, or <code>transactionId</code> value can't be found.</p>
     *   - {ServiceUnavailableError} <p>The service specified by the <code>resourceArn</code> parameter is not
                available.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    commitTransaction(args: CommitTransactionInput): Promise<CommitTransactionOutput>;
    commitTransaction(args: CommitTransactionInput, cb: (err: any, data?: CommitTransactionOutput) => void): void;
    /**
     * <p>Runs one or more SQL statements.</p>
            <important>
                <p>This operation is deprecated. Use the <code>BatchExecuteStatement</code> or
                        <code>ExecuteStatement</code> operation.</p>
            </important>
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} <p>There is an error in the call or in a SQL statement.</p>
     *   - {ForbiddenException} <p>There are insufficient privileges to make the call.</p>
     *   - {InternalServerErrorException} <p>An internal error occurred.</p>
     *   - {ServiceUnavailableError} <p>The service specified by the <code>resourceArn</code> parameter is not
                available.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    executeSql(args: ExecuteSqlInput): Promise<ExecuteSqlOutput>;
    executeSql(args: ExecuteSqlInput, cb: (err: any, data?: ExecuteSqlOutput) => void): void;
    /**
     * <p>Runs a SQL statement against a database.</p>
            <important>
                <p>If a call isn't part of a transaction because it doesn't include the
                        <code>transactionID</code> parameter, changes that result from the call are
                    committed automatically.</p>
            </important>
            <p>The response size limit is 1 MB or 1,000 records. If the call returns more than 1 MB of response data or over 1,000 records, the call is terminated.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} <p>There is an error in the call or in a SQL statement.</p>
     *   - {ForbiddenException} <p>There are insufficient privileges to make the call.</p>
     *   - {InternalServerErrorException} <p>An internal error occurred.</p>
     *   - {ServiceUnavailableError} <p>The service specified by the <code>resourceArn</code> parameter is not
                available.</p>
     *   - {StatementTimeoutException} <p>The execution of the SQL statement timed out.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    executeStatement(args: ExecuteStatementInput): Promise<ExecuteStatementOutput>;
    executeStatement(args: ExecuteStatementInput, cb: (err: any, data?: ExecuteStatementOutput) => void): void;
    /**
     * <p>Performs a rollback of a transaction. Rolling back a transaction cancels its changes.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BadRequestException} <p>There is an error in the call or in a SQL statement.</p>
     *   - {ForbiddenException} <p>There are insufficient privileges to make the call.</p>
     *   - {InternalServerErrorException} <p>An internal error occurred.</p>
     *   - {NotFoundException} <p>The <code>resourceArn</code>, <code>secretArn</code>, or <code>transactionId</code> value can't be found.</p>
     *   - {ServiceUnavailableError} <p>The service specified by the <code>resourceArn</code> parameter is not
                available.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    rollbackTransaction(args: RollbackTransactionInput): Promise<RollbackTransactionOutput>;
    rollbackTransaction(args: RollbackTransactionInput, cb: (err: any, data?: RollbackTransactionOutput) => void): void;
}
